#
# spec file for package siege
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           siege
Version:        4.0.4
Release:        bp153.1.16
Summary:        HTTP Regression Testing/Benchmarking Utility
License:        GPL-2.0+
Group:          Productivity/Networking/Web/Utilities
Url:            https://www.joedog.org/siege-home/
Source:         http://download.joedog.org/siege/siege-%{version}.tar.gz
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
%{perl_requires}

%description
Siege is a regression test and benchmark utility. It can stress test a
single URL with a user defined number of simulated users, or it can read
many URLs into memory and stress them simultaneously. The program reports
the total number of hits recorded, bytes transferred, response time,
concurrency, and return status. Siege supports HTTP/1.0 and 1.1 protocols,
GET and POST directives, cookies, transaction logging, and basic
authentication. Its features are configurable on a per user basis. Since
3.0.0 it also supports FTP.

%prep
%setup -q

%build
%configure \
  --sysconfdir="%{_sysconfdir}/%{name}"
make %{?_smp_mflags}

%install
%make_install

%files
%doc AUTHORS ChangeLog COPYING README.md
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/siegerc
%config(noreplace) %{_sysconfdir}/%{name}/urls.txt
%{_bindir}/bombardment
%{_bindir}/siege
%{_bindir}/siege2csv.pl
%{_bindir}/siege.config
%{_mandir}/man1/bombardment.1%{ext_man}
%{_mandir}/man1/siege.1%{ext_man}
%{_mandir}/man1/siege.config.1%{ext_man}
%{_mandir}/man1/siege2csv.1%{ext_man}

%changelog
* Fri Sep 15 2017 mpluskal@suse.com
- Update to version 4.0.4:
  * For full list of changes see attached ChangeLog
* Fri Mar 24 2017 mpluskal@suse.com
- Update to version 4.0.2:
  * For full list of changes see attached ChangeLog
* Sun Mar 20 2016 mpluskal@suse.com
- Remove timestamp
* Mon Dec 21 2015 mpluskal@suse.com
- Make it build on SLE11
* Sun Dec  6 2015 mpluskal@suse.com
- Update to 3.1.3
  * mostly bugfix release
  * see ChangeLog for details
* Wed Sep  2 2015 mpluskal@suse.com
- Update to 3.1.0
  * This release adds support for more than 1024 concurrent users.
    (Please don’t use that many unless you know what you’re doing).
    It also adds delay granularity. You can now select set delays
    to hundreds of a second like this: –delay=0.001 or -d 0.001
* Tue Mar 10 2015 mpluskal@suse.com
- Correct download url
* Tue Mar 10 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Remove obsolete %%debug_package
- Remove unnecessary dependencies
* Tue Mar 10 2015 mrueckert@suse.de
- SIEGE-3.0.9 – This release is intended to bring siege into the
  21st Century. It fixes lots of compiler warnings which are thrown
  by more recent versions of gcc. While it contains no sexy new
  features, you should probably upgrade to this version.
- SIEGE-3.0.8 – This release adds the port number to a redirect URL
  on the condition that request is made to a non-standard port. It
  also adds the location of the log file on logging errors. This
  should make it easier for users to correct their problem. “Oh,
  look, it’s trying to log to a location that doesn’t exist.”
- SIEGE-3.0.7 This release fixes a bug introduced in siege-3.0.6.
  Rather than strictly adhere to the RFC, siege will construct an
  absolute URL from a relative one. While this is convenient it
  missed a usecase. Siege-3.0.6 barfs on Location: http://localhost
  All siege 3.0.6 users should upgrade to 3.0.7.
- SIEGE-3.0.6 With this release, siege changes the way it handles
  –reps=once. It now divides a urls.txt file evenly among all its
  users, and each URL in the file is hit exactly once. This release
  also includes several fixes and a documentation update.
- SIEGE-3.0.5 This release addresses another inconsistency between
  the HTTP standard and practice. While RFC 2616 allows a port
  designation in the Host header, it confuses too many
  implementations for Siege to continue to send it. This version
  also fixes several significant bugs. All Siege users should
  update to this version.
- SIEGE-3.0.4 Although RFC 2616 specifies that Location directives
  must contain an absolute URI, most Web clients normalize relative
  URIs. This release adds conventional compliance with relative URI
  handling. Ironically, it also includes a new default user-agent
  so that field is in compliance with RFC 2616.
* Mon Aug 19 2013 pascal.bleser@opensuse.org
- update to 3.0.3:
  * adds URL escaping: reserved characters are %%-encoded as per RFC 3986
  * numerous bugfixes such as improved variable evaluation in the urls.txt
    file, dynamic Accept-Encoding, improved siegerc parsing, and several memory
    fixes
  * fixes a siegerc parser bug which was inadvertently introduced in the 3.0.x
    line: in those versions, siege ignores entries with leading whitespace
  * adds URL escaping along with an option to turn the feature off
  * removes chunked encoding from -g/--get requests to make the output more
    human-readable
- changes from 3.0.2:
  * bugfix release
  * corrects a significant problem with POSTs in version 3.0.1
  * all 3.0.1 users should upgrade to this version.
- changes from 3.0.1:
  * provides a new method for looping through a URLs file: each client now
    begins at a different location in the file
  * provides support for long URLs and POST data
  * includes several bugfixes and documentation updates
* Wed Apr 10 2013 pascal.bleser@opensuse.org
- update to 3.0.0:
  * significant portions have been rewritten to add support for additional protocols
  * adds limited support for FTP: you can get and put files to a server; FTP is
    invoked automatically based on the URL scheme, i.e., ftp://
* Tue Apr 17 2012 pascal.bleser@opensuse.org
- update to 2.73b2:
  * refines the fix for Debian bug debian#665407
  * adds conditionals for backward compatibility
* Sun Apr 15 2012 pascal.bleser@opensuse.org
- update to 2.73b1:
  * use /dev/urandom on machines which support it for improved randomness
- changes from 2.72:
  * corrects a thirteen year old bug: if you don't provide a '-f file'
    argument, siege will now look for urls.txt inside the $sysconfdir you set
    at configure time
- changes from 2.72b1:
  * fixes a 13-year bug: Siege now uses $sysconfdir/urls.txt as its default
    urls.txt file; this is in accordance with existing documentation
- cumulative changes from 2.71 and its betas:
  * adds the option of timestamping each output line while in verbose mode
  * introduces numerous bugfixes and code refinements
  * changes default verbosity setting from true to false
  * allows to override the Host header with the -H/--header option
  * fixes a memory allocation problem which could lead to segmentation faults
  * several minor bug fixes
  * allows the user to add timestamps to the output; they can be turned on or
    off with timestamp=true|false in the .siegerc file
  * fix for incorrect cookie expiration on some platforms
* Sat Jul 17 2010 pascal.bleser@opensuse.org
- update to 2.70:
  * provides a mechanism to allow siege to log in as a variety of different users
  * fixes a bug in which cookies weren't sent if the domain had a leading dot
  * adds colorized output and color-coded error messages
* Tue May 12 2009 pascal.bleser@opensuse.org
- update to 2.69:
  * minor improvements in memory management and error notification
* Tue Apr 28 2009 pascal.bleser@opensuse.org
- moved to openSUSE Build Service
- update to 2.68
* Tue Apr  3 2007 guru@unixtech.be
- new upstream version
- CHANGES: adds an appropriate Content-type for file posts
- CHANGES: numerous fixes, most importantly cookie expiration handling and a
  problem associated with parsing the .siegerc configuration file
* Tue Apr 18 2006 guru@unixtech.be
- rewrote spec file
- new upstream version
* Tue Sep 27 2005 guru@unixtech.be
- new package
